/// <reference types="react" />
export declare type Opacity = 'linear' | 'log';
export declare type Ordering = 'alpha' | 'clust' | 'rank' | 'rank_var';
export declare type NRowSums = 'all' | string | number;
export declare type Distribution = 'cos' | string;
export declare type NetworkDataNode = {
    name: string;
    clust: number;
    rank: number;
    rankvar?: number;
    group?: number[];
    ini?: number;
};
export declare type NetworkDataView = {
    N_row_sum?: NRowSums;
    dist: Distribution;
    nodes: {
        row_nodes: NetworkDataNode[];
        col_nodes: NetworkDataNode[];
    };
};
export declare type NetworkDataLink = {
    source: number;
    target: number;
    value: number;
    value_up?: boolean;
    value_dn?: boolean;
};
export declare type NetworkData = {
    row_nodes: NetworkDataNode[];
    col_nodes: NetworkDataNode[];
    links?: NetworkDataLink[];
    mat?: number[][];
    views: NetworkDataView[];
};
export interface ClustergrammerProps {
    root: string;
    network: NetworkData;
    row_label?: string;
    col_label?: string;
    row_label_scale?: number;
    col_label_scale?: number;
    super_label_scale?: number;
    opacity_scale?: Opacity;
    input_domain?: number;
    do_zoom?: boolean;
    tile_colors?: [string, string];
    row_order?: Ordering;
    col_order?: Ordering;
    ini_view?: string;
    about?: string;
    row_tip_callback?: (root_id: string, row_data: NetworkDataNode) => void;
}
export declare type ClustergrammerGLNetwork = {
    manual_category: Record<string, string | {
        name: string;
        color: string;
    }[]>;
    matrix_colors: {
        pos: string;
        red: string;
    };
    order: {
        row: Ordering;
        col: Ordering;
    };
};
export interface ClustergrammerGLArgs extends Omit<ClustergrammerProps, "network"> {
    container: HTMLElement | null;
    widget_callback?: (externalModel: any) => void;
    network_data: NetworkData;
    viz_width?: number;
    viz_height?: number;
}
export declare const ClustergramReact: (props: ClustergrammerGLArgs) => JSX.Element;
