import { jsx as _jsx } from "react/jsx-runtime";
import axios from 'axios';
import clustergrammerGL from 'clustergrammer-gl';
import * as d3 from 'd3';
import { memoize } from 'lodash';
import { useEffect, useRef, useState } from 'react';
export const ClustergramReact = (props) => {
    const { root: containerId } = props;
    const containerRef = useRef(null);
    const [geneData, setGeneData] = useState({});
    const updateRowTooltip = memoize((root, symbol) => {
        d3.selectAll(root + '_row_tip').html(function () {
            return `<div><p>${symbol}</p><p>${geneData[symbol]}</p></div>`;
        });
    });
    const rowTooltipCallback = memoize((root_id, row_data) => {
        if (geneData[row_data.name] !== undefined) {
            updateRowTooltip(root_id, row_data.name);
        }
        else {
            axios.get('https://amp.pharm.mssm.edu/Harmonizome/api/1.0/gene/' + row_data.name).then((res) => {
                setGeneData((prev) => ({
                    ...geneData,
                    [row_data.name]: res.data['description'] !== '' ? res.data['description'] : 'No description available.',
                }));
                updateRowTooltip(root_id, row_data.name);
            });
        }
    });
    useEffect(() => {
        if (containerRef.current !== null && document.querySelector(`#${containerId} .loading`)) {
            var ro = new ResizeObserver(() => {
                cg.resize_viz();
            });
            // Observe one or multiple elements
            ro.observe(containerRef.current);
            const clustergrammerArgs = {
                row_tip_callback: rowTooltipCallback,
                root: containerId,
                container: containerRef.current,
                network: props.network_data,
            };
            const cg = clustergrammerGL(clustergrammerArgs);
            document.querySelector(`#${containerRef.current.id} .loading`)?.remove();
        }
    }, [containerRef]);
    return (_jsx("div", { className: "text-center", children: _jsx("div", { id: containerId, ref: containerRef, children: _jsx("h3", { className: "loading", children: "Loading..." }) }) }));
};
